@@ -14,12 +14,12 @@
 
 // Qt includes
 #include "discover_debug.h"
-#include <QAction>
 #include <QClipboard>
 #include <QDBusConnection>
 #include <QDBusMessage>
 #include <QDBusPendingCall>
 #include <QDesktopServices>
+#include <QFile>
 #include <QGuiApplication>
 #include <QPointer>
 #include <QQmlApplicationEngine>
@@ -34,7 +34,6 @@
 // KDE includes
 #include <KAboutData>
 #include <KAuthorized>
-#include <KConcatenateRowsProxyModel>
 #include <KConfigGroup>
 #include <KCrash>
 #include <KLocalizedContext>
@@ -100,7 +99,6 @@ DiscoverObject::DiscoverObject(CompactMode mode, const QVariantMap &initialPrope
 
     qmlRegisterType<UnityLauncher>("org.kde.discover.app", 1, 0, "UnityLauncher");
     qmlRegisterType<PaginateModel>("org.kde.discover.app", 1, 0, "PaginateModel");
-    qmlRegisterType<KConcatenateRowsProxyModel>("org.kde.discover.app", 1, 0, "KConcatenateRowsProxyModel");
     qmlRegisterType<FeaturedModel>("org.kde.discover.app", 1, 0, "FeaturedModel");
     qmlRegisterType<OurSortFilterProxyModel>("org.kde.discover.app", 1, 0, "QSortFilterProxyModel");
 #ifdef WITH_FEEDBACK
@@ -115,8 +113,6 @@ DiscoverObject::DiscoverObject(CompactMode mode, const QVariantMap &initialPrope
         return r;
     });
     qmlRegisterAnonymousType<QQuickView>("org.kde.discover.app", 1);
-    qmlRegisterAnonymousType<QActionGroup>("org.kde.discover.app", 1);
-    qmlRegisterAnonymousType<QAction>("org.kde.discover.app", 1);
 
     qmlRegisterAnonymousType<KAboutData>("org.kde.discover.app", 1);
     qmlRegisterAnonymousType<KAboutLicense>("org.kde.discover.app", 1);
@@ -153,7 +149,7 @@ DiscoverObject::DiscoverObject(CompactMode mode, const QVariantMap &initialPrope
                 Q_EMIT openErrorPage(
                     i18n("Discover currently cannot be used to install any apps "
                          "because none of its app backends are available. Please "
-                         "report this error to your distribution."));
+                         "report this issue to the packagers of your distribution."));
         },
         this);
 
@@ -307,7 +303,11 @@ void DiscoverObject::openApplication(const QUrl &url)
                     openApplication(QUrl(QStringLiteral("appstream://org.kde.discover.snap")));
                     showPassiveNotification(i18n("Please make sure Snap support is installed"));
                 } else {
-                    Q_EMIT openErrorPage(i18n("Could not open %1", url.toDisplayString()));
+                    Q_EMIT openErrorPage(
+                        i18n("Could not open %1 because it was not found in any "
+                             "available software repositories. Please report this "
+                             "issue to the packagers of your distribution.",
+                             url.toDisplayString()));
                 }
             });
         },
@@ -377,11 +377,6 @@ bool DiscoverObject::eventFilter(QObject *object, QEvent *event)
     return false;
 }
 
-QAction *DiscoverObject::action(const QString &name) const
-{
-    return m_collection.value(name);
-}
-
 QString DiscoverObject::iconName(const QIcon &icon)
 {
     return icon.name();
@@ -475,6 +470,12 @@ void DiscoverObject::showPassiveNotification(const QString &msg)
     });
 }
 
+void DiscoverObject::copyTextToClipboard(const QString text)
+{
+    QClipboard *clipboard = QGuiApplication::clipboard();
+    clipboard->setText(text);
+}
+
 void DiscoverObject::reboot()
 {
     auto method = QDBusMessage::createMethodCall(QStringLiteral("org.kde.LogoutPrompt"),
@@ -484,6 +485,16 @@ void DiscoverObject::reboot()
     QDBusConnection::sessionBus().asyncCall(method);
 }
 
+void DiscoverObject::rebootNow()
+{
+    auto method = QDBusMessage::createMethodCall(QStringLiteral("org.freedesktop.login1"),
+                                                 QStringLiteral("/org/freedesktop/login1"),
+                                                 QStringLiteral("org.freedesktop.login1.Manager"),
+                                                 QStringLiteral("Reboot"));
+    method.setArguments({true /*interactive*/});
+    QDBusConnection::systemBus().asyncCall(method);
+}
+
 QRect DiscoverObject::initialGeometry() const
 {
     KConfigGroup window(KSharedConfig::openConfig(), "Window");
