@@ -6,33 +6,44 @@
 
 #include "updates.h"
 
-#include <KConfigGroup>
-#include <KPluginFactory>
 #include <KAboutData>
+#include <KConfigGroup>
 #include <KLocalizedString>
+#include <KPluginFactory>
+
+#include <discoverdata.h>
 
 #include <updatesdata.h>
-#include <updatessettings.h>
 
 K_PLUGIN_FACTORY_WITH_JSON(UpdatesFactory, "kcm_updates.json", registerPlugin<Updates>(); registerPlugin<UpdatesData>();)
 
 Updates::Updates(QObject *parent, const QVariantList &args)
     : KQuickAddons::ManagedConfigModule(parent)
     , m_data(new UpdatesData(this))
+    , m_discoverData(new DiscoverData(this))
 {
     Q_UNUSED(args)
 
     qmlRegisterAnonymousType<UpdatesSettings>("org.kde.discover.updates", 1);
+    qmlRegisterAnonymousType<DiscoverSettings>("org.kde.discover.updates", 1);
 
     setAboutData(new KAboutData(QStringLiteral("kcm_updates"),
-                                       i18n("Software Updates"),
-                                       QStringLiteral("1.0"), i18n("Configure software update settings"), KAboutLicense::LGPL));
+                                i18n("Software Update"),
+                                QStringLiteral("1.0"),
+                                i18n("Configure software update settings"),
+                                KAboutLicense::LGPL));
 }
 
 Updates::~Updates() = default;
+
 UpdatesSettings *Updates::updatesSettings() const
 {
     return m_data->settings();
 }
 
+DiscoverSettings *Updates::discoverSettings() const
+{
+    return m_discoverData->settings();
+}
+
 #include "updates.moc"
