@@ -13,10 +13,7 @@
 
 ReviewsModel::ReviewsModel(QObject *parent)
     : QAbstractListModel(parent)
-    , m_app(nullptr)
-    , m_backend(nullptr)
     , m_lastPage(0)
-    , m_canFetchMore(true)
 {
 }
 
@@ -172,3 +169,5 @@ void ReviewsModel::flagReview(int row, const QString &reason, const QString &tex
     Review *r = m_reviews[row].data();
     m_backend->flagReview(r, reason, text);
 }
+
+#include "moc_ReviewsModel.cpp"
