@@ -7,6 +7,8 @@
 
 #include "FlatpakResource.h"
 #include "FlatpakBackend.h"
+#include "FlatpakFetchDataJob.h"
+#include "FlatpakPermission.h"
 #include "FlatpakSourcesBackend.h"
 #include "config-paths.h"
 
@@ -16,6 +18,8 @@
 #include <AppStreamQt/screenshot.h>
 #include <appstream/AppStreamUtils.h>
 
+#include <KConfigGroup>
+#include <KDesktopFile>
 #include <KFormat>
 #include <KLocalizedString>
 
@@ -30,6 +34,7 @@
 #include <QNetworkRequest>
 #include <QProcess>
 #include <QStringList>
+#include <QTemporaryFile>
 #include <QTimer>
 #include <QUrlQuery>
 
@@ -39,7 +44,8 @@ static QString iconCachePath(const AppStream::Icon &icon)
     return QStringLiteral("%1/icons/%2").arg(QStandardPaths::writableLocation(QStandardPaths::CacheLocation), icon.url().fileName());
 }
 
-const QStringList FlatpakResource::m_objects{QStringLiteral("qrc:/qml/FlatpakAttention.qml")};
+const QStringList FlatpakResource::s_objects({QStringLiteral("qrc:/qml/FlatpakAttention.qml"), QStringLiteral("qrc:/qml/FlatpakRemoveData.qml")});
+const QStringList FlatpakResource::s_bottomObjects({QStringLiteral("qrc:/qml/PermissionsList.qml")});
 
 FlatpakResource::FlatpakResource(const AppStream::Component &component, FlatpakInstallation *installation, FlatpakBackend *parent)
     : AbstractResource(parent)
@@ -81,6 +87,8 @@ FlatpakResource::FlatpakResource(const AppStream::Component &component, FlatpakI
             }
         }
     }
+
+    connect(this, &FlatpakResource::stateChanged, this, &FlatpakResource::hasDataButUninstalledChanged);
 }
 
 AppStream::Component FlatpakResource::appstreamComponent() const
@@ -177,7 +185,7 @@ QString FlatpakResource::commit() const
     return m_commit;
 }
 
-int FlatpakResource::downloadSize() const
+quint64 FlatpakResource::downloadSize() const
 {
     return m_downloadSize;
 }
@@ -230,13 +238,17 @@ QString FlatpakResource::installedVersion() const
         version = i18n("Unknown");
     }
 
-    if (auto ref = qobject_cast<FlatpakBackend *>(backend())->getInstalledRefForApp(this)) {
-        return i18nc("version (branch)", "%1 (%2)", flatpak_installed_ref_get_appdata_version(ref), version);
+    g_autoptr(FlatpakInstalledRef) ref = qobject_cast<FlatpakBackend *>(backend())->getInstalledRefForApp(this);
+    if (ref) {
+        const char *appdataVersion = flatpak_installed_ref_get_appdata_version(ref);
+        if (appdataVersion) {
+            return i18nc("version (branch)", "%1 (%2)", appdataVersion, version);
+        }
     }
     return version;
 }
 
-int FlatpakResource::installedSize() const
+quint64 FlatpakResource::installedSize() const
 {
     return m_installedSize;
 }
@@ -318,6 +330,14 @@ QString FlatpakResource::attentionText() const
     return {};
 }
 
+QAbstractListModel *FlatpakResource::permissionsModel()
+{
+    if (m_permissions.empty()) {
+        loadPermissions();
+    }
+    return new FlatpakPermissionsModel(m_permissions);
+}
+
 QString FlatpakResource::name() const
 {
     QString name = m_appdata.name();
@@ -362,7 +382,7 @@ QString FlatpakResource::section()
     return QString();
 }
 
-int FlatpakResource::size()
+quint64 FlatpakResource::size()
 {
     if (m_state == Installed) {
         return m_installedSize;
@@ -477,7 +497,7 @@ void FlatpakResource::setCommit(const QString &commit)
     m_commit = commit;
 }
 
-void FlatpakResource::setDownloadSize(int size)
+void FlatpakResource::setDownloadSize(quint64 size)
 {
     m_downloadSize = size;
 
@@ -501,7 +521,7 @@ void FlatpakResource::setIconPath(const QString &path)
     m_iconPath = path;
 }
 
-void FlatpakResource::setInstalledSize(int size)
+void FlatpakResource::setInstalledSize(quint64 size)
 {
     m_installedSize = size;
 
@@ -537,13 +557,14 @@ void FlatpakResource::setRuntime(const QString &runtime)
     setPropertyState(RequiredRuntime, AlreadyKnown);
 }
 
-void FlatpakResource::setState(AbstractResource::State state)
+void FlatpakResource::setState(AbstractResource::State state, bool shouldEmit)
 {
     if (m_state != state) {
         m_state = state;
 
-        if (!backend()->isFetching())
+        if (shouldEmit && qobject_cast<FlatpakBackend *>(backend())->isTracked(this)) {
             Q_EMIT stateChanged();
+        }
     }
 }
 
@@ -600,7 +621,13 @@ QString FlatpakResource::sourceIcon() const
 
 QString FlatpakResource::author() const
 {
-    return m_appdata.developerName();
+    QString name = m_appdata.developerName();
+
+    if (name.isEmpty()) {
+        name = m_appdata.projectGroup();
+    }
+
+    return name;
 }
 
 QStringList FlatpakResource::extends() const
@@ -641,3 +668,190 @@ QString FlatpakResource::versionString()
 
     return AppStreamUtils::versionString(version, m_appdata);
 }
+
+QString translateSymbolicName(const QStringView &name)
+{
+    if (name == QLatin1String("host")) {
+        return i18n("All Files");
+    } else if (name == QLatin1String("home")) {
+        return i18n("Home");
+    } else if (name == QLatin1String("xdg-download")) {
+        return i18n("Downloads");
+    } else if (name == QLatin1String("xdg-music")) {
+        return i18n("Music");
+    }
+    return name.toString();
+}
+
+void FlatpakResource::loadPermissions()
+{
+    QByteArray metaDataBytes = FlatpakRunnables::fetchMetadata(this, NULL);
+
+    QTemporaryFile f;
+    if (!f.open()) {
+        return;
+    }
+    f.write(metaDataBytes);
+    f.close();
+
+    KDesktopFile parser(f.fileName());
+
+    QString brief, description;
+
+    const KConfigGroup contextGroup = parser.group("Context");
+    const QString shared = contextGroup.readEntry("shared", QString());
+    if (shared.contains("network")) {
+        brief = i18n("Network Access");
+        description = i18n("Can access the internet");
+        m_permissions.append(FlatpakPermission(brief, description, "network-wireless"));
+    }
+    if (shared.contains("session-bus")) {
+        brief = i18n("Session Bus Access");
+        description = i18n("Access is granted to the entire Session Bus");
+        m_permissions.append(FlatpakPermission(brief, description, "system-save-session"));
+    }
+    if (shared.contains("system-bus")) {
+        brief = i18n("System Bus Access");
+        description = i18n("Access is granted to the entire System Bus");
+        m_permissions.append(FlatpakPermission(brief, description, "system-save-session"));
+    }
+    if (shared.contains("ssh-auth")) {
+        brief = i18n("Remote Login Access");
+        description = i18n("Can initiate remote login requests using the SSH protocol");
+        m_permissions.append(FlatpakPermission(brief, description, "x-shape-connection"));
+    }
+    if (shared.contains("pcsc")) {
+        brief = i18n("Smart Card Access");
+        description = i18n("Can integrate and communicate with smart cards");
+        m_permissions.append(FlatpakPermission(brief, description, "network-card"));
+    }
+
+    if (shared.contains("kvm")) {
+        brief = i18n("Kernel-based Virtual Machine Access");
+        description = i18n("Allows running other operating systems as guests in virtual machines");
+        m_permissions.append(FlatpakPermission(brief, description, "virtualbox"));
+    }
+
+    const QString devices = contextGroup.readEntry("devices", QString());
+    if (devices.contains("all")) {
+        brief = i18n("Device Access");
+        description = i18n("Can communicate with and control built-in or connected hardware devices");
+        m_permissions.append(FlatpakPermission(brief, description, "preferences-devices-tree"));
+    }
+
+    const QString filesystems = contextGroup.readEntry("filesystems", QString());
+    const auto dirs = QStringView(filesystems).split(';', Qt::SkipEmptyParts);
+    QStringList homeList, systemList;
+    bool home_ro = false, home_rw = false, home_cr = false, homeAccess = false;
+    bool system_ro = false, system_rw = false, system_cr = false, systemAccess = false;
+
+    bool hasHostRW = false;
+
+    for (const QStringView &dir : dirs) {
+        if (dir == QLatin1String("xdg-config/kdeglobals:ro")) {
+            // Ignore notifying about the global file being visible, since it's intended by design
+            continue;
+        }
+
+        int separator = dir.lastIndexOf(':');
+        const QStringView postfix = separator > 0 ? dir.mid(separator) : QStringView();
+        const QStringView symbolicName = dir.left(separator);
+        const QString id = translateSymbolicName(symbolicName);
+        if ((dir.contains(QLatin1String("home")) || dir.contains(QChar('~')))) {
+            if (postfix == QLatin1String(":ro")) {
+                homeList << i18n("%1 (read-only)", id);
+                home_ro = true;
+            } else if (postfix == QLatin1String(":create")) {
+                homeList << i18n("%1 (can create files)", id);
+                home_cr = true;
+            } else {
+                homeList << i18n("%1 (read & write) ", id);
+                home_rw = true;
+            }
+            homeAccess = true;
+        } else if (!hasHostRW) {
+            if (postfix == QLatin1String(":ro")) {
+                systemList << i18n("%1 (read-only)", id);
+                system_ro = true;
+            } else if (postfix == QLatin1String(":create")) {
+                systemList << i18n("%1 (can create files)", id);
+                system_cr = true;
+            } else {
+                // Once we have host in rw, no need to list the rest
+                if (symbolicName == QLatin1String("host")) {
+                    hasHostRW = true;
+                    systemList.clear();
+                }
+
+                systemList << i18n("%1 (read & write) ", id);
+                system_rw = true;
+            }
+            systemAccess = true;
+        }
+    }
+
+    QString appendText = "\n- " + homeList.join("\n- ");
+    if (homeAccess) {
+        brief = i18n("Home Folder Access");
+        if (home_rw && home_ro && home_cr) {
+            description =
+                i18n("Can read, write, and create files in the following locations in your home folder without asking permission first: %1", appendText);
+        } else if (home_rw && !home_cr) {
+            description = i18n("Can read and write files in the following locations in your home folder without asking permission first: %1", appendText);
+        } else if (home_ro && !home_cr && !home_rw) {
+            description = i18n("Can read files in the following locations in your home folder without asking permission first: %1", appendText);
+        } else {
+            description = i18n("Can access files in the following locations in your home folder without asking permission first: %1", appendText);
+        }
+        m_permissions.append(FlatpakPermission(brief, description, "inode-directory"));
+    }
+    appendText = "\n- " + systemList.join("\n- ");
+    if (systemAccess) {
+        brief = i18n("System Folder Access");
+        if (system_rw && system_ro && system_cr) {
+            description = i18n("Can read, write, and create system files in the following locations without asking permission first: %1", appendText);
+        } else if (system_rw && !system_cr) {
+            description = i18n("Can read and write system files in the following locations without asking permission first: %1", appendText);
+        } else if (system_ro && !system_cr && !system_rw) {
+            description = i18n("Can read system files in the following locations without asking permission first: %1", appendText);
+        } else {
+            description = i18n("Can access system files in the following locations without asking permission first: %1", appendText);
+        }
+        m_permissions.append(FlatpakPermission(brief, description, "inode-directory"));
+    }
+
+    const KConfigGroup sessionBusGroup = parser.group("Session Bus Policy");
+    if (sessionBusGroup.exists()) {
+        const QStringList busList = sessionBusGroup.keyList();
+        brief = i18n("Session Bus Access");
+        description = i18n("Can communicate with other applications and processes in the same desktop session using the following communication protocols: %1",
+                           "\n- " + busList.join("\n- "));
+        m_permissions.append(FlatpakPermission(brief, description, "system-save-session"));
+    }
+
+    const KConfigGroup systemBusGroup = parser.group("System Bus Policy");
+    if (systemBusGroup.exists()) {
+        const QStringList busList = systemBusGroup.keyList();
+        brief = i18n("System Bus Access");
+        description =
+            i18n("Can communicate with all applications and system services using the following communication protocols: %1", "\n- " + busList.join("\n- "));
+        m_permissions.append(FlatpakPermission(brief, description, "system-save-session"));
+    }
+}
+
+QString FlatpakResource::dataLocation() const
+{
+    auto id = m_appdata.bundle(AppStream::Bundle::KindFlatpak).id();
+    return QDir::homePath() + QLatin1String("/.var/") + id.section('/', 0, 1);
+}
+
+bool FlatpakResource::hasDataButUninstalled() const
+{
+    return m_state == None && QDir(dataLocation()).exists();
+}
+
+void FlatpakResource::clearUserData()
+{
+    QDir(dataLocation()).removeRecursively();
+    Q_EMIT hasDataButUninstalledChanged();
+}
