@@ -91,16 +91,18 @@ private:
     void markInvalid(const QString &message);
     void searchStream(ResultsStream *stream, const QString &searchText);
     void fetchMore();
+    void setResponsePending(bool pending);
 
     bool m_onePage = false;
     bool m_responsePending = false;
+    QString m_pendingSearchQuery;
     bool m_fetching;
     bool m_isValid;
     KNSCore::Engine *m_engine;
     QHash<QString, AbstractResource *> m_resourcesByName;
     KNSReviews *const m_reviews;
     QString m_name;
-    QString m_iconName;
+    const QString m_iconName;
     StandardBackendUpdater *const m_updater;
     QStringList m_extends;
     QStringList m_categories;
