@@ -13,7 +13,6 @@
 #include <QRegularExpression>
 
 #include "ReviewsBackend/Rating.h"
-#include <knewstuff_version.h>
 
 KNSResource::KNSResource(const KNSCore::EntryInternal &entry, QStringList categories, KNSBackend *parent)
     : AbstractResource(parent)
@@ -134,10 +133,10 @@ QJsonArray KNSResource::licenses()
     return {QJsonObject{{QStringLiteral("name"), m_entry.license()}, {QStringLiteral("url"), QString()}}};
 }
 
-int KNSResource::size()
+quint64 KNSResource::size()
 {
     const auto downloadInfo = m_entry.downloadLinkInformationList();
-    return downloadInfo.isEmpty() ? 0 : downloadInfo.at(0).size;
+    return downloadInfo.isEmpty() ? 0 : downloadInfo.at(0).size * 1024;
 }
 
 QString KNSResource::installedVersion() const
