@@ -68,7 +68,7 @@ ResourcesModel::ResourcesModel(QObject *parent, bool load)
                   for (auto backend : qAsConst(m_backends)) {
                       sum += backend->fetchingUpdatesProgress();
                   }
-                  return sum / m_backends.count();
+                  return sum / (int)m_backends.count();
               }
           },
           [this](int progress) {
@@ -148,6 +148,7 @@ void ResourcesModel::addResourcesBackend(AbstractResourcesBackend *backend)
     });
     connect(backend, &AbstractResourcesBackend::resourceRemoved, this, &ResourcesModel::resourceRemoved);
     connect(backend, &AbstractResourcesBackend::passiveMessage, this, &ResourcesModel::passiveMessage);
+    connect(backend, &AbstractResourcesBackend::inlineMessage, this, &ResourcesModel::inlineMessage);
     connect(backend->backendUpdater(), &AbstractBackendUpdater::progressingChanged, this, &ResourcesModel::slotFetching);
     if (backend->reviewsBackend()) {
         connect(backend->reviewsBackend(), &AbstractReviewsBackend::error, this, &ResourcesModel::passiveMessage, Qt::UniqueConnection);
@@ -421,5 +422,5 @@ QString ResourcesModel::applicationSourceName() const
 
 QUrl ResourcesModel::distroBugReportUrl()
 {
-    return KOSRelease().bugReportUrl();
+    return QUrl(KOSRelease().bugReportUrl());
 }
