@@ -116,6 +116,8 @@ public:
         return m_fetchingUpdatesProgress.m_value;
     }
 
+    Q_INVOKABLE QUrl distroBugReportUrl();
+
 public Q_SLOTS:
     void installApplication(AbstractResource *app, const AddonList &addons);
     void installApplication(AbstractResource *app);
@@ -132,6 +134,7 @@ Q_SIGNALS:
     void passiveMessage(const QString &message);
     void currentApplicationBackendChanged(AbstractResourcesBackend *currentApplicationBackend);
     void fetchingUpdatesProgressChanged(int fetchingUpdatesProgress);
+    void inlineMessage(int type, const QString &iconName, const QString &message);
 
 private Q_SLOTS:
     void callerFetchingChanged();
